from flask import Blueprint

bp = Blueprint(
    'blueprint',
    __name__,
    url_prefix='/blueprint',
    template_folder='templates',
    static_folder='static',
)


@bp.get('/')
def index():
    return 'Hello World, now in blueprint'



import shutil
from pathlib import Path

import toml
import typer
from .utils import without_special_characters_input


def create(directory: str, extension: bool = False) -> None:
    root = Path(__file__).parent.absolute()
    app_name = (
        without_special_characters_input('Digite o nome do app: ')
        .lower()
        .replace(' ', '_')
    )
    folder = Path(directory) / app_name
    shutil.rmtree(folder, ignore_errors=True)
    shutil.copytree(root / 'base', folder)
    shutil.move(folder / 'project_name', folder / app_name)
    if extension:
        with open(folder / app_name / '__init__.py', 'r') as file:
            app_class_name = app_name.title().replace('_', '')
            content = file.read()
            content = content.replace('Extension', app_class_name)
        with open(folder / app_name / '__init__.py', 'w') as file:
            file.write(content)
    else:
        with open(folder / app_name / '__init__.py', 'w') as file:
            file.write('')
    with open(folder / 'tests' / 'conftest.py', 'r') as file:
        content = file.read().replace('project_name', app_name)
    with open(folder / 'tests' / 'conftest.py', 'w') as file:
        file.write(content)
    config = toml.load(open(folder / 'config.toml', 'r'))
    config['extensions'].append(f'{app_name}.views')
    config['extensions'].append(f'{app_name}.blueprint')
    toml.dump(config, open(folder / 'config.toml', 'w'))
    with open(folder / '.env', 'r') as file:
        content = file.read().replace('project_name', app_name)
    with open(folder / '.env', 'w') as file:
        file.write(content)


def run() -> None:
    typer.run(create)



import pytest
from flask import Flask
from flask.testing import FlaskClient
from project_name.app import create_app


@pytest.fixture(scope='module')
def app() -> Flask:
    app = create_app()
    app.config['TESTING'] = True
    yield app


@pytest.fixture(scope='module')
def client(app: Flask) -> FlaskClient:
    return app.test_client()



from importlib import import_module

import toml
from flask import Flask


def init_app(app: Flask) -> None:
    config = toml.load(open('config.toml', 'r'))
    secret_config = toml.load(open('.secret.toml', 'r'))
    for extension in config['extensions']:
        module = import_module(extension)
        module.init_app(app)
    app.config['SECRET_KEY'] = secret_config['secret_key']



import os
import string


def without_special_characters_input(prompt: str) -> str:
    while True:
        result = input(prompt)
        if [
            letter
            for letter in result
            if letter not in string.ascii_letters + string.digits + ' '
        ]:
            input(
                (
                    'Não digite caracteres especiais. Aperte Enter para contin'
                    'uar...'
                )
            )
            os.system('cls' if os.name == 'nt' else 'clear')
        else:
            break
    return result



from flask import Flask


class Extension:
    def __init__(self, app: Flask) -> None:
        if app is not None:
            self.init_app(app)

    def init_app(self, app: Flask) -> None:
        pass
